@@ -19,7 +19,7 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include <gnu_gama/list.h>
+#include <list>
 #include <cmath>
 
 #ifndef GNU_gama_obsdata_h_gnugamaobsdata_observation_data_gnu_gama_obsdata
@@ -40,7 +40,7 @@ namespace GNU_gama {
 
       typedef Observation                     ObservationType;
       const ObservationData<Observation>*     observation_data;
-      List<Observation*>                      observation_list;
+      std::list<Observation*>                 observation_list;
       typename Observation::CovarianceMatrix  covariance_matrix;
 
 
@@ -85,9 +85,9 @@ namespace GNU_gama {
     {
     public:
 
-      typedef Observation           ObservationType;
-      typedef Cluster<Observation>  ClusterType;
-      typedef List<ClusterType*>    ClusterList;
+      typedef Observation             ObservationType;
+      typedef Cluster<Observation>    ClusterType;
+      typedef std::list<ClusterType*> ClusterList;
 
       ClusterList                   clusters;
 
@@ -155,7 +155,7 @@ namespace GNU_gama {
 
           const ObservationData*  OD;
           typename ObservationData::ClusterList::const_iterator  cluster;
-          typename List<Observation*>::const_iterator            obs;
+          typename std::list<Observation*>::const_iterator       obs;
         };
 
       const_iterator  begin() const
@@ -249,7 +249,7 @@ namespace GNU_gama {
 
           ObservationData*  OD;
           typename ObservationData::ClusterList::iterator  cluster;
-          typename List<Observation*>::iterator            obs;
+          typename std::list<Observation*>::iterator       obs;
         };
 
       iterator  begin()
@@ -293,7 +293,7 @@ namespace GNU_gama {
   template <typename Observation>
     Cluster<Observation>::~Cluster()
     {
-      for (typename List<Observation*>::iterator
+      for (typename std::list<Observation*>::iterator
              i=observation_list.begin(); i!=observation_list.end() ;  ++i)
         {
           delete *i;
@@ -310,7 +310,7 @@ namespace GNU_gama {
       act_nonz  = 0;
       int index = 0;
       Observation* p;
-      for (typename List<Observation*>::iterator
+      for (typename std::list<Observation*>::iterator
              i=observation_list.begin(); i!=observation_list.end(); ++i)
         {
           p = (*i);
@@ -337,11 +337,8 @@ namespace GNU_gama {
     typename Observation::CovarianceMatrix
        Cluster<Observation>::activeCov() const
     {
-      typedef std::size_t Index;
-      // const Index M      = covariance_matrix.rows();
-      const Index N      = activeDim();
-      // const Index i_size = observation_list.size();
-      Index active_band  = covariance_matrix.bandWidth();
+      const int N     = activeDim();
+      int active_band = covariance_matrix.bandWidth();
 
       if (N)
         {
@@ -351,17 +348,17 @@ namespace GNU_gama {
         active_band = 0;
 
       typename Observation::CovarianceMatrix C(N, active_band);
-      Index* ind = new Index[act_dim + 1];
-      Index  k=1, n=1;
+      int* ind = new int[act_dim + 1];
+      int  k=1, n=1;
 
-      for (typename List<Observation*>::const_iterator
+      for (typename std::list<Observation*>::const_iterator
              i=observation_list.begin(),
              e=observation_list.end(); i!=e; ++i)
         {
           const Observation* obs = *i;
 
           if (obs->active())
-            for (int /*Index*/ d=0; d < obs->dimension(); d++)
+            for (int d=0; d < obs->dimension(); d++)
               {
                 ind[k++] = n + d;
               }
@@ -369,8 +366,8 @@ namespace GNU_gama {
           n += obs->dimension();
         }
 
-      for (Index i=1; i<=N; i++)
-        for (Index j=0; j<=active_band && i+j<=N; j++)
+      for (int i=1; i<=N; i++)
+        for (int j=0; j<=active_band && i+j<=N; j++)
           C(i, i+j) = covariance_matrix(ind[i], ind[i+j]);
 
       delete[] ind;
@@ -386,8 +383,10 @@ namespace GNU_gama {
       const int B = covariance_matrix.bandWidth();
       int k = p + B;
       if (k > N) k = N;
-      int  q = p - B;
-      if (q < 1) q = 1;
+      // int  q = p - B;
+      // if (q < 1) q = 1;
+      /* unsigned safe version: */
+      int q = (p < B+1) ? 1 : p-B;
 
       // scaling upper part of symmetric band matrix
       covariance_matrix(p, p) *= sc;
@@ -402,7 +401,7 @@ namespace GNU_gama {
   template <typename Observation>
     ObservationData<Observation>::~ObservationData()
     {
-      for (typename List<Cluster<Observation>*>::iterator
+      for (typename std::list<Cluster<Observation>*>::iterator
              c=clusters.begin(); c!=clusters.end(); ++c)
         {
           delete *c;
@@ -417,7 +416,7 @@ namespace GNU_gama {
     {
       if (this != &cod)
         {
-          for (typename List<Cluster<Observation>*>::iterator
+          for (typename std::list<Cluster<Observation>*>::iterator
                  c=clusters.begin(); c!=clusters.end(); ++c) delete *c;
           {
             deepCopy(cod);
@@ -432,16 +431,16 @@ namespace GNU_gama {
   template <typename Observation>
     void ObservationData<Observation>::deepCopy(const ObservationData& cod)
     {
-      for (typename List<Cluster<Observation>*>::const_iterator
+      for (typename std::list<Cluster<Observation>*>::const_iterator
              ci=cod.clusters.begin(); ci!=cod.clusters.end(); ++ci)
         {
           Cluster<Observation>* current = (*ci)->clone(this);
 
-          typename List<Observation*>::const_iterator
+          typename std::list<Observation*>::const_iterator
             begin = (*ci)->observation_list.begin();
-          typename List<Observation*>::const_iterator
+          typename std::list<Observation*>::const_iterator
             end   = (*ci)->observation_list.end();
-          for (typename List<Observation*>::const_iterator
+          for (typename std::list<Observation*>::const_iterator
                  m=begin; m!=end; ++m)
             {
               current->observation_list.push_back( (*m)->clone() );
