@@ -27,7 +27,6 @@
 
 #include <gnu_gama/xml_expat.h>
 #include <gnu_gama/intfloat.h>
-#include <gnu_gama/size_to.h>
 #include <string>
 #include <list>
 
@@ -45,7 +44,7 @@ namespace GNU_gama {
     virtual void xml_parse(const char *s, int len, int  isFinal) = 0;
     void xml_parse(const std::string& s, bool isFinal)
     {
-      xml_parse(s.c_str(), size_to<int>(s.length()), isFinal ? 1 : 0);
+      xml_parse(s.c_str(), static_cast<int>(s.length()), isFinal ? 1 : 0);
     }
     virtual int characterDataHandler(const char* s, int len) = 0;
     virtual int startElement(const char *cname, const char **atts) = 0;
