@@ -1,6 +1,6 @@
 /* GNU Gama C++ library
-   Copyright (C) 1999, 2002, 2003, 2010, 2011, 2012, 2014, 2018, 2020, 2021
-                 Ales Cepek <cepek@gnu.org>
+   Copyright (C) 1999, 2002, 2003, 2010, 2011, 2012, 2014, 2018, 2020, 2021,
+                 2025  Ales Cepek <cepek@gnu.org>
 
    This file is part of the GNU Gama C++ library.
 
@@ -27,6 +27,7 @@
 #include <cstring>
 #include <gnu_gama/version.h>
 #include <gnu_gama/intfloat.h>
+#include <gnu_gama/xml_expat.h>
 #include <gnu_gama/xml/localnetworkoctave.h>
 #include <gnu_gama/xml/localnetworkxml.h>
 #include <gnu_gama/xml/gkfparser.h>
@@ -61,8 +62,10 @@ int help()
 
   cout << "\n"
        << "Adjustment of local geodetic network"
-       << "        version: "<< GNU_gama::GNU_gama_version()
-       << " / " << GNU_gama::GNU_gama_compiler() << "\n"
+       << "        version: "<< GNU_gama::version()
+       << " / " << GNU_gama::compiler()
+       << " / expat " << XML_MAJOR_VERSION << "." << XML_MINOR_VERSION
+       << "\n"
        << "************************************\n"
        << "https://www.gnu.org/software/gama/\n\n";
 
@@ -156,7 +159,7 @@ int main(int argc, char **argv)
             GNU_gama::version("gama-local", "Ales Cepek et al.");
         if (!strcmp(c, "dumpversion"))
           {
-            cout << GNU_gama::GNU_gama_version() << endl;
+            cout << GNU_gama::version() << endl;
             return 0;
           }
       }
@@ -504,9 +507,9 @@ int main(int argc, char **argv)
 
     {
       cout << T_GaMa_Adjustment_of_geodetic_network << "        "
-           << T_GaMa_version << GNU_gama::GNU_gama_version()
+           << T_GaMa_version << GNU_gama::version()
            << "-" << IS->algorithm()
-           << " / " << GNU_gama::GNU_gama_compiler() << "\n"
+           << " / " << GNU_gama::compiler() << "\n"
            << underline(T_GaMa_Adjustment_of_geodetic_network, '*') << "\n"
            << "http://www.gnu.org/software/gama/\n\n";
     }
@@ -713,7 +716,7 @@ int main(int argc, char **argv)
         if (network_can_be_adjusted && argv_export_xml)
           {
             std::string ver = "<!-- created by gama-local "
-                + GNU_gama::GNU_gama_version() + " -->\n";
+                + GNU_gama::version() + " -->\n";
             std::string xml = IS->export_xml(ver);
 
             if (!strcmp(argv_export_xml, "-"))
